@@ -35,9 +35,11 @@ class InputSource : public SampleSource<std::complex<float>>
 private:
     QFile *inputFile = nullptr;
     size_t sampleCount = 0;
-    size_t sampleRate = 0;
+    double sampleRate = 0.0;
     uchar *mmapData = nullptr;
     std::unique_ptr<SampleAdapter> sampleAdapter;
+    std::string _fmt;
+    bool _realSignal = false;
 
 public:
     InputSource();
@@ -48,8 +50,12 @@ public:
     size_t count() {
         return sampleCount;
     };
-    void setSampleRate(size_t rate);
-    size_t rate();
+    void setSampleRate(double rate);
+    void setFormat(std::string fmt);
+    double rate();
+    bool realSignal() {
+        return _realSignal;
+    };
     float relativeBandwidth() {
         return 1;
     }
