@@ -35,7 +35,7 @@ class PlotView : public QGraphicsView, Subscriber
 
 public:
     PlotView(InputSource *input);
-    void setSampleRate(size_t rate);
+    void setSampleRate(double rate);
 
 signals:
     void timeSelectionChanged(float time);
@@ -46,7 +46,7 @@ public slots:
     void cursorsMoved();
     void enableCursors(bool enabled);
     void enableScales(bool enabled);
-    void invalidateEvent();
+    void invalidateEvent() override;
     void repaint();
     void setCursorSegments(int segments);
     void setFFTAndZoom(int fftSize, int zoomLevel);
@@ -55,10 +55,11 @@ public slots:
 
 protected:
     void contextMenuEvent(QContextMenuEvent * event) override;
-    void paintEvent(QPaintEvent *event);
-    void resizeEvent(QResizeEvent * event);
-    void scrollContentsBy(int dx, int dy);
+    void paintEvent(QPaintEvent *event) override;
+    void resizeEvent(QResizeEvent * event) override;
+    void scrollContentsBy(int dx, int dy) override;
     bool viewportEvent(QEvent *event) override;
+    void showEvent(QShowEvent *event) override;
 
 private:
     Cursors cursors;
@@ -71,11 +72,11 @@ private:
     size_t zoomSample;
 
     int fftSize = 1024;
-    int zoomLevel = 0;
+    int zoomLevel = 1;
     int powerMin;
     int powerMax;
     bool cursorsEnabled;
-    size_t sampleRate = 0;
+    double sampleRate = 0.0;
     bool timeScaleEnabled;
     int scrollZoomStepsAccumulated = 0;
 
@@ -87,7 +88,7 @@ private:
     int plotsHeight();
     size_t samplesPerColumn();
     void updateViewRange(bool reCenter);
-    void updateView(bool reCenter = false);
+    void updateView(bool reCenter = false, bool expanding = false);
     void paintTimeScale(QPainter &painter, QRect &rect, range_t<size_t> sampleRange);
 
     int sampleToColumn(size_t sample);
