@@ -51,6 +51,9 @@ SpectrogramPlot::SpectrogramPlot(std::shared_ptr<SampleSource<std::complex<float
 
 void SpectrogramPlot::invalidateEvent()
 {
+    // HACK: this makes sure we update the height for real signals (as InputSource is passed here before the file is opened)
+    setFFTSize(fftSize);
+
     pixmapCache.clear();
     fftCache.clear();
     emit repaint();
@@ -71,6 +74,8 @@ void SpectrogramPlot::paintFrequencyScale(QPainter &painter, QRect &rect)
     int y = rect.y();
 
     int plotHeight = rect.height();
+    if (inputSource->realSignal())
+        plotHeight *= 2;
 
     double bwPerPixel = (double)sampleRate / plotHeight;
     int tickHeight = 50;
@@ -95,7 +100,8 @@ void SpectrogramPlot::paintFrequencyScale(QPainter &painter, QRect &rect)
         int tickpy = plotHeight / 2 - tick / bwPerPixel + y;
         int tickny = plotHeight / 2 + tick / bwPerPixel + y;
 
-        painter.drawLine(0, tickny, 30, tickny);
+        if (!inputSource->realSignal())
+            painter.drawLine(0, tickny, 30, tickny);
         painter.drawLine(0, tickpy, 30, tickpy);
 
         if (tick != 0) {
@@ -109,7 +115,8 @@ void SpectrogramPlot::paintFrequencyScale(QPainter &painter, QRect &rect)
                 snprintf(buf, sizeof(buf), "-%d Hz", tick);
             }
 
-            painter.drawText(5, tickny - 5, buf);
+            if (!inputSource->realSignal())
+                painter.drawText(5, tickny - 5, buf);
 
             buf[0] = ' ';
             painter.drawText(5, tickpy + 15, buf);
@@ -128,7 +135,8 @@ void SpectrogramPlot::paintFrequencyScale(QPainter &painter, QRect &rect)
             int tickpy = plotHeight / 2 - tick / bwPerPixel + y;
             int tickny = plotHeight / 2 + tick / bwPerPixel + y;
 
-            painter.drawLine(0, tickny, 3, tickny);
+            if (!inputSource->realSignal())
+                painter.drawLine(0, tickny, 3, tickny);
             painter.drawLine(0, tickpy, 3, tickpy);
 
             tick += bwPerTick;
@@ -147,14 +155,14 @@ void SpectrogramPlot::paintMid(QPainter &painter, QRect &rect, range_t<size_t> s
     int xoffset = sampleOffset / getStride();
 
     // Paint first (possibly partial) tile
-    painter.drawPixmap(QRect(rect.left(), rect.y(), linesPerTile() - xoffset, fftSize), *getPixmapTile(tileID), QRect(xoffset, 0, linesPerTile() - xoffset, fftSize));
+    painter.drawPixmap(QRect(rect.left(), rect.y(), linesPerTile() - xoffset, height()), *getPixmapTile(tileID), QRect(xoffset, 0, linesPerTile() - xoffset, height()));
     tileID += getStride() * linesPerTile();
 
     // Paint remaining tiles
     for (int x = linesPerTile() - xoffset; x < rect.right(); x += linesPerTile()) {
         // TODO: don't draw past rect.right()
         // TODO: handle partial final tile
-        painter.drawPixmap(QRect(x, rect.y(), linesPerTile(), fftSize), *getPixmapTile(tileID));
+        painter.drawPixmap(QRect(x, rect.y(), linesPerTile(), height()), *getPixmapTile(tileID), QRect(0, 0, linesPerTile(), height()));
         tileID += getStride() * linesPerTile();
     }
 }
@@ -249,7 +257,7 @@ std::vector<float> SpectrogramPlot::getTunerTaps()
     float cutoff = tuner.deviation() / (float)fftSize;
     float gain = pow(10.0f, powerMax / -10.0f);
     auto atten = 60.0f;
-    auto len = estimate_req_filter_len(0.05f, atten);
+    auto len = estimate_req_filter_len(std::min(cutoff, 0.05f), atten);
     auto taps = std::vector<float>(len);
     liquid_firdes_kaiser(len, cutoff, atten, 0.0f, taps.data());
     std::transform(taps.begin(), taps.end(), taps.begin(),
@@ -286,10 +294,14 @@ void SpectrogramPlot::setFFTSize(int size)
         window[i] = 0.5f * (1.0f - cos(Tau * i / (fftSize - 1)));
     }
 
-    setHeight(fftSize);
+    if (inputSource->realSignal()) {
+        setHeight(fftSize/2);
+    } else {
+        setHeight(fftSize);
+    }
     auto dev = tuner.deviation();
     auto centre = tuner.centre();
-    tuner.setHeight(fftSize);
+    tuner.setHeight(height());
     tuner.setDeviation( dev * sizeScale );
     tuner.setCentre( centre * sizeScale );
 }
@@ -331,7 +343,7 @@ void SpectrogramPlot::tunerMoved()
 {
     tunerTransform->setFrequency(getTunerPhaseInc());
     tunerTransform->setTaps(getTunerTaps());
-    tunerTransform->setRelativeBandwith(tuner.deviation() * 2.0 / getStride());
+    tunerTransform->setRelativeBandwith(tuner.deviation() * 2.0 / height());
 
     // TODO: for invalidating traceplot cache, this shouldn't really go here
     QPixmapCache::clear();
